Stan Math Library: stan/math/prim/scal/meta/VectorBuilder.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces
VectorBuilder.hpp File Reference
`#include <stan/math/prim/scal/meta/VectorBuilderHelper.hpp>`
`#include <stan/math/prim/scal/meta/contains_vector.hpp>`

Go to the source code of this file.

## Classes
class | stan::VectorBuilder< used, T1, T2, T3, T4, T5, T6, T7 >
| VectorBuilder allocates type T1 values to be used as intermediate values. More...

## Namespaces
| stan

[ Stan Home Page ] © 2011–2016, Stan Development Team.